@@ -459,6 +459,18 @@ def login(admin_username=None, admin_password=None):
 
     return ETH_IAM_conn(admin_username, admin_password, hostname, endpoint_base)
 
+def get_username_password(ctx):
+
+    if ctx.obj['username'] is None:
+        ctx.obj['username'] = click.prompt(
+            text='Username', 
+            default=os.environ.get('USER', ''),
+            show_default=True,
+        )
+
+    if ctx.obj['password'] is None:
+        ctx.obj['password'] = click.prompt(text='Password', hide_input=True)
+
 
 @click.command()
 @click.argument('group')
@@ -484,8 +496,13 @@ def login(admin_username=None, admin_password=None):
 )
 @click.pass_context
 def group(ctx, group, delete, members, info, add=None, remove=None):
+    """group modifications.
+    """
     if add is None: add = ()
     if remove is None: remove = ()
+
+    get_username_password(ctx)
+
     e = login(ctx.obj['username'], ctx.obj['password'])
     group = e.get_group(group)
 
@@ -506,19 +523,20 @@ def group(ctx, group, delete, members, info, add=None, remove=None):
 
 
 #default=os.environ.get('NEO4J_HOSTNAME')
+#@click.option('--password', prompt=True, hide_input=True,
+#    help='password of your ETHZ IAM admin account')
 @click.group()
 @click.option('-u', '--username',
-    default=lambda: os.environ.get('USER', ''),
-    show_default='',
     help='username of your ETHZ IAM admin account')
+@click.option('--password', 
+    help='password of your ETHZ IAM admin account (if not provided, it will be prompted)')
 @click.option('-h', '--host',
-    default= "https://iam.passwort.ethz.ch"
+    default= "https://iam.passwort.ethz.ch",
+    help="default: https://iam.passwort.ethz.ch"
 )
-@click.option('--password', prompt=True, hide_input=True,
-    help='password of your ETHZ IAM admin account')
 @click.pass_context
-def cli(ctx, host, username, password):
-    """This is the main entry point for the CLI
+def cli(ctx, host, username, password=None):
+    """ETHZ IAM command-line tool.
     """
     ctx.ensure_object(dict)
     ctx.obj['host'] = host
